==> jc-1.4.0.tar.gz: java/awt/event/ComponentAdapter.h <==
// public abstract class java.awt.event.ComponentAdapter

// class file dependencies
// @dep_class 40238674ada23301 java_awt_event_ComponentAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_ComponentAdapter_H_
#define _JC_java_awt_event_ComponentAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_ComponentEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_ComponentAdapter$sub_refs	_jc_java_awt_event_ComponentAdapter$sub_refs;
typedef struct _jc_java_awt_event_ComponentAdapter$sub_nonrefs	_jc_java_awt_event_ComponentAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_ComponentAdapter$refs	_jc_java_awt_event_ComponentAdapter$refs;
typedef struct _jc_java_awt_event_ComponentAdapter$nonrefs	_jc_java_awt_event_ComponentAdapter$nonrefs;
typedef struct _jc_java_awt_event_ComponentAdapter$object	_jc_java_awt_event_ComponentAdapter$object;

typedef const struct _jc_java_awt_event_ComponentAdapter$vmethods	_jc_java_awt_event_ComponentAdapter$vmethods;
typedef const struct _jc_java_awt_event_ComponentAdapter$vtable	_jc_java_awt_event_ComponentAdapter$vtable;
typedef const struct _jc_java_awt_event_ComponentAdapter$vtype	_jc_java_awt_event_ComponentAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_ComponentAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *);

// Virtual methods
extern void _jc_java_awt_event_ComponentAdapter$method$componentHidden$c45a3d9480cd8f67(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *);
extern void _jc_java_awt_event_ComponentAdapter$method$componentMoved$81a358183048de7c(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *);
extern void _jc_java_awt_event_ComponentAdapter$method$componentResized$ac5fcd90b88c07ec(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *);
extern void _jc_java_awt_event_ComponentAdapter$method$componentShown$f9db658060a8b292(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_ComponentAdapter$method_info$componentHidden$c45a3d9480cd8f67;
extern _jc_method _jc_java_awt_event_ComponentAdapter$method_info$componentMoved$81a358183048de7c;
extern _jc_method _jc_java_awt_event_ComponentAdapter$method_info$componentResized$ac5fcd90b88c07ec;
extern _jc_method _jc_java_awt_event_ComponentAdapter$method_info$componentShown$f9db658060a8b292;

// Virtual methods structure
struct _jc_java_awt_event_ComponentAdapter$vmethods {
	void	(*componentHidden$c45a3d9480cd8f67)(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *);
	void	(*componentMoved$81a358183048de7c)(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *);
	void	(*componentResized$ac5fcd90b88c07ec)(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *);
	void	(*componentShown$f9db658060a8b292)(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *);
};

// Vtable
struct _jc_java_awt_event_ComponentAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_ComponentAdapter$vmethods	java_awt_event_ComponentAdapter;
};

// Vtype
struct _jc_java_awt_event_ComponentAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_ComponentAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_ComponentAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_ComponentAdapter$refs {
    _jc_java_awt_event_ComponentAdapter$sub_refs	java_awt_event_ComponentAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_ComponentAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_ComponentAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_ComponentAdapter$sub_nonrefs	java_awt_event_ComponentAdapter;
};

// Object instance structure
struct _jc_java_awt_event_ComponentAdapter$object {
	_jc_java_awt_event_ComponentAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_ComponentAdapter$vtype	*vtype;
	_jc_java_awt_event_ComponentAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_ComponentAdapter$vtype _jc_java_awt_event_ComponentAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_ComponentAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_ComponentAdapter$class_object;

#endif	/* _JC_java_awt_event_ComponentAdapter_H_ */

==> jc-1.4.6.tar.gz: java/awt/event/ComponentAdapter.h <==
// public abstract class java.awt.event.ComponentAdapter

// class file dependencies
// @dep_class 40238674ada23301 java_awt_event_ComponentAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_ComponentAdapter_H_
#define _JC_java_awt_event_ComponentAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_ComponentEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_ComponentAdapter$sub_refs	_jc_java_awt_event_ComponentAdapter$sub_refs;
typedef struct _jc_java_awt_event_ComponentAdapter$sub_nonrefs	_jc_java_awt_event_ComponentAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_ComponentAdapter$refs	_jc_java_awt_event_ComponentAdapter$refs;
typedef struct _jc_java_awt_event_ComponentAdapter$nonrefs	_jc_java_awt_event_ComponentAdapter$nonrefs;
typedef struct _jc_java_awt_event_ComponentAdapter$object	_jc_java_awt_event_ComponentAdapter$object;

typedef const struct _jc_java_awt_event_ComponentAdapter$vmethods	_jc_java_awt_event_ComponentAdapter$vmethods;
typedef const struct _jc_java_awt_event_ComponentAdapter$vtable	_jc_java_awt_event_ComponentAdapter$vtable;
typedef const struct _jc_java_awt_event_ComponentAdapter$vtype	_jc_java_awt_event_ComponentAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_ComponentAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_event_ComponentAdapter$method$componentHidden$c45a3d9480cd8f67(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_ComponentAdapter$method$componentMoved$81a358183048de7c(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_ComponentAdapter$method$componentResized$ac5fcd90b88c07ec(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_ComponentAdapter$method$componentShown$f9db658060a8b292(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_ComponentAdapter$method_info$componentHidden$c45a3d9480cd8f67;
extern _jc_method _jc_java_awt_event_ComponentAdapter$method_info$componentMoved$81a358183048de7c;
extern _jc_method _jc_java_awt_event_ComponentAdapter$method_info$componentResized$ac5fcd90b88c07ec;
extern _jc_method _jc_java_awt_event_ComponentAdapter$method_info$componentShown$f9db658060a8b292;

// Virtual methods structure
struct _jc_java_awt_event_ComponentAdapter$vmethods {
	void	(*componentHidden$c45a3d9480cd8f67)(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
	void	(*componentMoved$81a358183048de7c)(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
	void	(*componentResized$ac5fcd90b88c07ec)(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
	void	(*componentShown$f9db658060a8b292)(_jc_env *, struct _jc_java_awt_event_ComponentAdapter$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_ComponentAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_ComponentAdapter$vmethods	java_awt_event_ComponentAdapter;
};

// Vtype
struct _jc_java_awt_event_ComponentAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_ComponentAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_ComponentAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_ComponentAdapter$refs {
    _jc_java_awt_event_ComponentAdapter$sub_refs	java_awt_event_ComponentAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_ComponentAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_ComponentAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_ComponentAdapter$sub_nonrefs	java_awt_event_ComponentAdapter;
};

// Object instance structure
struct _jc_java_awt_event_ComponentAdapter$object {
	_jc_java_awt_event_ComponentAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_ComponentAdapter$vtype	*vtype;
	_jc_java_awt_event_ComponentAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_ComponentAdapter$vtype _jc_java_awt_event_ComponentAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_ComponentAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_ComponentAdapter$class_object;

#endif	/* _JC_java_awt_event_ComponentAdapter_H_ */
